Class: Cartage::CLI::CommandException

Inherits:
GLI::CommandException
  • Object
show all
Defined in:
lib/cartage/cli.rb

Overview

A local alias for GLI::CommandException. This exception is similar to CustomExit, but should be used when there is a configuration issue, or a conflict in flags or switches. It requires three parameters:

  1. The message;

  2. The command name for help (command.name_for_help);

  3. The exit status.