Module: Cartage::Core
- Included in:
- Cartage
- Defined in:
- lib/cartage/core.rb
Overview
Extensions for us to use to help define Cartage with its attr_readers with defaults and attr_writers with transforms.
Extensions for us to use to help define Cartage with its attr_readers with defaults and attr_writers with transforms.