Class: Cartage::CLI::CommandException
- Inherits:
-
GLI::CommandException
- Object
- GLI::CommandException
- Cartage::CLI::CommandException
- Defined in:
- lib/cartage/cli.rb
Overview
A local alias for GLI::CommandException. This exception is similar to CustomExit, but should be used when there is a configuration issue, or a conflict in flags or switches. It requires three parameters:
-
The message;
-
The command name for help (
command.name_for_help); -
The exit status.